==> haskell-microlens-ghc-0.4.8.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-ghc
version: 0.4.8.0
id: microlens-ghc-0.4.8.0-HkyUtqWBKMpJSdUj08iMnR
key: microlens-ghc-0.4.8.0-HkyUtqWBKMpJSdUj08iMnR
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).
    .
    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
indefinite: False
exposed-modules:
    Lens.Micro.GHC Lens.Micro.GHC.Internal
abi: 74efe0efee567db67eaa565ed12310fb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-ghc-0.4.8.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-ghc-0.4.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/microlens-ghc-0.4.8.0
hs-libraries: HSmicrolens-ghc-0.4.8.0-HkyUtqWBKMpJSdUj08iMnR
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    microlens-0.4.8.1-7SYUbX7BsEv8bVxypsAUmf transformers-0.5.2.0
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             microlens-0.4.8.1-7SYUbX7BsEv8bVxypsAUmf=0c34ea774f147d5f36c03bc1a30e0f6a
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock
haddock-html: /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-ghc-0.4.8.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-ghc
version: 0.4.8.0
id: microlens-ghc-0.4.8.0-LgyzN1fsM1jJTR3dDQxT6S
key: microlens-ghc-0.4.8.0-LgyzN1fsM1jJTR3dDQxT6S
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).
    .
    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
indefinite: False
exposed-modules:
    Lens.Micro.GHC Lens.Micro.GHC.Internal
abi: b98657680335e2dd5328708ffa5de5b9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-ghc-0.4.8.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/microlens-ghc-0.4.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/microlens-ghc-0.4.8.0
hs-libraries: HSmicrolens-ghc-0.4.8.0-LgyzN1fsM1jJTR3dDQxT6S
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote transformers-0.5.2.0
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote=c565b163852cf4d98393719d821091b2
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock
haddock-html: /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
